---
name: Feature request
about: Propose a new feature
title: ''
labels: 'enhancement'
assignees: ''
---

**Does the feature exist in the most recent commit?**

We recommend using the latest commit from GitHub in your projects.

**Why do we need this feature?**

Ideally, explain why a combination of existing features cannot be used instead.

**Describe the proposal**

Include a detailed description of the feature, with usage examples.

**Is the feature specific to an operating system, compiler, or build system version?**

If it is, please specify which versions.

